@@ -16,7 +16,7 @@ from svnpublish import framework, subversion, revinfo
 from ..test_helper import TestCase, loadFileSystem, registerAllConfig
 
 #------------------------------------------------------------------------------
-class TestEmail(TestCase, pxml.TestMixin, genemail.testing.EmailTestMixin):
+class TestEmail(TestCase, pxml.XmlTestMixin, genemail.testing.EmailTestMixin):
 
   maxDiff  = None
   svnRepos = 'test/repos'
@@ -81,6 +81,7 @@ Content-Type: multipart/alternative; boundary="==MIMEBOUNDARY=z1-alt-2=="
 MIME-Version: 1.0
 To: rcpt@example.com
 From: "svnpublish" <noreply@localhost>
+Date: Fri, 13 Feb 2009 23:31:30 -0000
 Subject: [SVN|TESTLABEL] r3 by svnuser - simple update with text changes
 
 --==MIMEBOUNDARY=z1-alt-2==
@@ -371,6 +372,7 @@ Content-Type: multipart/alternative; boundary="==MIMEBOUNDARY=z1-alt-2=="
 MIME-Version: 1.0
 To: rcpt@example.com
 From: "svnpublish" <noreply@localhost>
+Date: Fri, 13 Feb 2009 23:31:30 -0000
 Subject: [SVN|TESTLABEL] r3 by svnuser - simple update with text changes
 
 --==MIMEBOUNDARY=z1-alt-2==
@@ -674,6 +676,7 @@ Content-Type: multipart/alternative; boundary="==MIMEBOUNDARY=z1-alt-2=="
 MIME-Version: 1.0
 To: rcpt@example.com
 From: "svnpublish" <noreply@localhost>
+Date: Fri, 13 Feb 2009 23:31:30 -0000
 Subject: [SVN|TESTLABEL] r3 by svnuser - simple update with text changes
 
 --==MIMEBOUNDARY=z1-alt-2==
